@@ -20,21 +20,25 @@ def is_date(schema: dict):
     return schema['type'] == "string" and schema['format'] == "date"
 
 
-def parse_type(schema: dict) -> str:
+def parse_type(schema: dict, nullable: bool = False) -> str:
     format = None
     if "format" in schema:
         format = schema['format'].lower()
     type = schema['type'].lower()
+    if nullable:
+        suffix = "?"
+    else:
+        suffix = ""
     if type == "string" and format == "uuid":
-        return "System.Guid"
-    if type == "string" and format == "date-time":
-        return "System.DateTime"
-    if type == "string" and format == "date":
-        return "System.DateTime"
+        return f"System.Guid{suffix}"
+    if type == "string" and format in ["date-time", "date"]:
+        return f"System.DateTime{suffix}"
     if type == "integer":
-        return "int"
+        return f"int{suffix}"
     if type == "number":
-        return "double"
+        return f"double{suffix}"
     if type == "boolean":
-        return "bool"
-    return type
+        return f"bool{suffix}"
+    if type == "string":
+        return "string" # no nullable suffix for string
+    return f"{type}{suffix}"
